==> patch-2.5.5.3_1.zip: app/templates/default/header.php <==
<?php use Helpers\Assets; use Helpers\Url; ?>
<!DOCTYPE html>
<html lang="en" ng-app="myApp" ng-controller="MainController">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta http-equiv="Content-Security-Policy" content="upgrade-insecure-requests">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <meta name="description" content="">
    <meta name="author" content="">
    <link rel="icon" href="<?=Url::templatePath()?>images/favicon.ico">
    <title><?php echo $data['title'].' - '.SITETITLE; ?></title>

    <!-- CSS -->
    <?php
        Assets::css(array(
            /* Core CSS */
//          Url::templatePath() . 'css/plugins/bootstrap.css',
//          Url::templatePath() . 'css/plugins/bootstrap_3.3.7.min.css',
//          Url::templatePath() . 'css/plugins/bootstrap.min.css',
//	    Url::templatePath() . 'css/plugins/jquery-ui.css',
	    Url::templatePath() . 'css/plugins/font-awesome_latest.min.css',		
	    Url::templatePath() . 'css/plugins/bootstrap_latest.min.css?'.VERSIONS_NUMBER,
	    Url::templatePath() . 'css/plugins/bootstrap-select_latest.min.css',
	    Url::templatePath() . 'css/plugins/jquery-ui.min.css',
            Url::templatePath() . 'css/plugins/nprogress.css',
            Url::templatePath() . 'css/plugins/select.min.css',
            Url::templatePath() . 'css/plugins/select2.min.css',
            Url::templatePath() . 'css/plugins/switchery.min.css',
            Url::templatePath() . 'css/plugins/toastr.min.css',
            Url::templatePath() . 'css/plugins/angular-block-ui.min.css',
//            Url::templatePath() . 'css/plugins/bootstrap-select.min.css',
            Url::templatePath() . 'css/plugins/bootstrap-datepicker.min.css',
            Url::templatePath() . 'css/plugins/timepicker.css',
            Url::templatePath() . 'css/plugins/bootstrap-tagsinput.css',
            Url::templatePath() . 'css/plugins/chosentree.css',
            Url::templatePath() . 'css/plugins/treeselect.css',
	    Url::templatePath() . 'css/plugins/bootstrap-toggle.min.css',
            Url::templatePath() . 'css/plugins/font-animation.css',

            /* Custom styles for this template */
            Url::templatePath() . 'css/style.css?'.VERSIONS_NUMBER,
            Url::templatePath() . 'css/plugins/search.css?'.VERSIONS_NUMBER,
        ));
    ?>

    <!-- HTML5 shim and Respond.js for IE8 support of HTML5 elements and media queries -->
    <!--[if lt IE 9]>
        <script src="<?php echo Url::templatePath(); ?>/js/plugins/html5shiv.min.js"></script>
        <script src="<?php echo Url::templatePath(); ?>/js/plugins/respond.min.js"></script>
    <![endif]-->
</head>
<?php if(ENABLE_IDEAL_TIMEOUT == true){?>
<script>
/*start*/

    // Set timeout variables.
var timoutWarning = 900000; // Display warning in 15 Mins.
var abc = <?php echo IDEAL_TIMEOUT;?>*60000;
var timoutNow = abc;

var warningTimer;
var timeoutTimer;

// Start timers.
function StartTimers() {
    warningTimer = setTimeout("IdleWarning()", timoutWarning);
    timeoutTimer = setTimeout("IdleTimeout()", timoutNow);
}

// Reset timers.
function ResetTimers() {
clearTimeout(warningTimer);
    clearTimeout(timeoutTimer);
    StartTimers();
//    $("#timeout").dialog('close');
}

// Show idle timeout warning dialog.
function IdleWarning() {
 /*$("#timeout").dialog({
        modal: true
    });*/
}

    /*end*/
</script>
<body onload="StartTimers();">
<?php }else{ ?>
<body>
<?php } ?>
<?php if(!array_key_exists('error',$data)){ ?>
<span class="d-none paracloudURL"><?=PARACLOUD_URL?></span>
<span class="d-none cloudNameConstant"><?=CLOUD_NAME?></span>
<span class="uploadUserName d-none"><?=$_SESSION['userName']?></span>
<span class="uploadToken d-none"><?=$_SESSION['token']?></span>
<span class="blukryptIPAddress d-none"><?=BLUKRYPT_URL?></span>
<span class="blukryptIP d-none"><?=BLUKRYPT_IP?></span>
<span class="blukryptURL d-none"><?=BLUKRPT_URL_WITHOUT_IP?></span>
<span class="paracloudIP d-none"><?=PARACLOUD_IP?></span>
<span class="protocol d-none"><?=PROTOCOL_DOWNLOAD?></span>
<span class="disableCutCopy d-none"><?php echo 'true';?></span>
<span class="backup_enabled d-none"><?=$_SESSION['backup_enabled']?></span>
<span class="sync_enabled d-none"><?=$_SESSION['sync_enabled']?></span>
<span class="one_drive_backup_enabled d-none"><?=$_SESSION['one_drive_backup_enabled']?></span>
<span class="exchange_backup_enabled d-none"><?=$_SESSION['exchange_backup_enabled']?></span>
<span class="Sharepoint_Backup_Enabled d-none"><?=$_SESSION['Sharepoint_Backup_Enabled']?></span>
<!--<span class="disableCutCopy hide"><?php if(DISABLE_CUT_COPY == true){echo 'false';}else{echo 'true';}?></span>-->
<?php } ?>

==> patch-2.5.5.3_7_2.zip: app/templates/default/header.php <==
<?php use Helpers\Assets; use Helpers\Url; ?>
<!DOCTYPE html>
<html lang="en" ng-app="myApp" ng-controller="MainController">
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta http-equiv="Content-Security-Policy" content="upgrade-insecure-requests">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <!-- The above 3 meta tags *must* come first in the head; any other head content must come *after* these tags -->
    <meta name="description" content="">
    <meta name="author" content="">
    <link rel="icon" href="<?=Url::templatePath()?>images/favicon.ico">
    <title><?php echo $data['title'].' - '.SITETITLE; ?></title>

    <!-- CSS -->
    <?php
        Assets::css(array(
            /* Core CSS */
//          Url::templatePath() . 'css/plugins/bootstrap.css',
//          Url::templatePath() . 'css/plugins/bootstrap_3.3.7.min.css',
//          Url::templatePath() . 'css/plugins/bootstrap.min.css',
//	    Url::templatePath() . 'css/plugins/jquery-ui.css',
	    Url::templatePath() . 'css/plugins/font-awesome_latest.min.css',		
	    Url::templatePath() . 'css/plugins/bootstrap_latest.min.css',
	    Url::templatePath() . 'css/plugins/bootstrap-select_latest.min.css',
	    Url::templatePath() . 'css/plugins/jquery-ui.min.css',
            Url::templatePath() . 'css/plugins/nprogress.css',
            Url::templatePath() . 'css/plugins/select.min.css',
            Url::templatePath() . 'css/plugins/select2.min.css',
            Url::templatePath() . 'css/plugins/switchery.min.css',
            Url::templatePath() . 'css/plugins/toastr.min.css',
            Url::templatePath() . 'css/plugins/angular-block-ui.min.css',
//            Url::templatePath() . 'css/plugins/bootstrap-select.min.css',
            Url::templatePath() . 'css/plugins/bootstrap-datepicker.min.css',
            Url::templatePath() . 'css/plugins/timepicker.css',
            Url::templatePath() . 'css/plugins/bootstrap-tagsinput.css',
            Url::templatePath() . 'css/plugins/chosentree.css',
            Url::templatePath() . 'css/plugins/treeselect.css',
	    Url::templatePath() . 'css/plugins/bootstrap-toggle.min.css',
            Url::templatePath() . 'css/plugins/font-animation.css',

            /* Custom styles for this template */
            Url::templatePath() . 'css/style.css',
            Url::templatePath() . 'css/plugins/search.css',
        ));
    ?>
</head>
<?php if(ENABLE_IDEAL_TIMEOUT == true){?>
<script>
/*start*/

    // Set timeout variables.
var timoutWarning = 900000; // Display warning in 15 Mins.
var abc = <?php echo IDEAL_TIMEOUT;?>*60000;
var timoutNow = abc;

var warningTimer;
var timeoutTimer;

// Start timers.
function StartTimers() {
    warningTimer = setTimeout("IdleWarning()", timoutWarning);
    timeoutTimer = setTimeout("IdleTimeout()", timoutNow);
}

// Reset timers.
function ResetTimers() {
clearTimeout(warningTimer);
    clearTimeout(timeoutTimer);
    StartTimers();
//    $("#timeout").dialog('close');
}

// Show idle timeout warning dialog.
function IdleWarning() {
 /*$("#timeout").dialog({
        modal: true
    });*/
}

    /*end*/
</script>
<body onload="StartTimers();">
<?php }else{ ?>
<body>
<?php } ?>
<?php if(!array_key_exists('error',$data)){ ?>
<span class="d-none paracloudURL"><?=PARACLOUD_URL?></span>
<span class="d-none cloudNameConstant"><?=CLOUD_NAME?></span>
<span class="uploadUserName d-none"><?=$_SESSION['userName']?></span>
<span class="uploadToken d-none"><?=$_SESSION['token']?></span>
<span class="blukryptIPAddress d-none"><?=BLUKRYPT_URL?></span>
<span class="blukryptIP d-none"><?=BLUKRYPT_IP?></span>
<span class="blukryptURL d-none"><?=BLUKRPT_URL_WITHOUT_IP?></span>
<span class="paracloudIP d-none"><?=PARACLOUD_IP?></span>
<span class="protocol d-none"><?=PROTOCOL_DOWNLOAD?></span>
<span class="cloud_url d-none"><?=CLOUD_URL?></span>
<span class="paracloud_name d-none"><?=PARACLOUD_NAME?></span>
<span class="cloud_urlAddress d-none"><?=PROTOCOL.CLOUD_URL.'/BluKryptBuilder/cloud/'?></span>
<span class="protocol d-none"><?=PROTOCOL_DOWNLOAD?></span>
<span class="disableCutCopy d-none"><?php echo 'true';?></span>
<span class="backup_enabled d-none"><?=$_SESSION['backup_enabled']?></span>
<span class="sync_enabled d-none"><?=$_SESSION['sync_enabled']?></span>
<span class="one_drive_backup_enabled d-none"><?=$_SESSION['one_drive_backup_enabled']?></span>
<span class="exchange_backup_enabled d-none"><?=$_SESSION['exchange_backup_enabled']?></span>
<span class="Sharepoint_Backup_Enabled d-none"><?=$_SESSION['Sharepoint_Backup_Enabled']?></span>
<span class="userType d-none"><?=$_SESSION['userType']?></span>
<!--<span class="disableCutCopy hide"><?php if(DISABLE_CUT_COPY == true){echo 'false';}else{echo 'true';}?></span>-->
<?php } ?>
<?php if(array_key_exists('error',$data)){ ?>
<span class="d-none paracloudURL"><?=PARACLOUD_URL?></span>
<span class="d-none cloudNameConstant"><?=CLOUD_NAME?></span>
<span class="blukryptIPAddress d-none"><?=BLUKRYPT_URL?></span>
<span class="blukryptIP d-none"><?=BLUKRYPT_IP?></span>
<span class="blukryptURL d-none"><?=BLUKRPT_URL_WITHOUT_IP?></span>
<span class="paracloudIP d-none"><?=PARACLOUD_IP?></span>
<span class="protocol d-none"><?=PROTOCOL_DOWNLOAD?></span>
<span class="cloud_url d-none"><?=CLOUD_URL?></span>
<span class="paracloud_name d-none"><?=PARACLOUD_NAME?></span>
<span class="cloud_urlAddress d-none"><?=PROTOCOL.CLOUD_URL.'/BluKryptBuilder/cloud/'?></span>
<span class="protocol d-none"><?=PROTOCOL_DOWNLOAD?></span>
<?php } ?>
